@@ -1,6 +1,3 @@
-#. TODO:
-#.
-
 #===============================================================================
 # This is the default class for handling Test::Base data filtering.
 #===============================================================================
@@ -213,7 +210,8 @@ sub lines {
 
 sub norm {
     $self->assert_scalar(@_);
-    my $text = shift || '';
+    my $text = shift;
+    $text = '' unless defined $text;
     $text =~ s/\015\012/\n/g;
     $text =~ s/\r/\n/g;
     return $text;
@@ -339,6 +337,8 @@ sub _write_to {
 
 __DATA__
 
+=encoding utf8
+
 =head1 NAME
 
 Test::Base::Filter - Default Filter Class for Test::Base
@@ -623,10 +623,11 @@ structure. Requires YAML.pm.
 
 =head1 AUTHOR
 
-Brian Ingerson <ingy@cpan.org>
+Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
+Copyright (c) 2006, 2011, 2014. Ingy döt Net. All rights reserved.
 Copyright (c) 2005. Brian Ingerson. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
